#include "geminc.h"
#include "gemprm.h"
#include "btcmn.h"

/*
**  Function prototypes.
*/

void bt_icpt( char [][8], char[][8], int * );

char *outstr( char [] );


/************************************************************************
 * bt_icpt                                                              *
 *                                                                      *
 * This routine prints the interface values arrays to the decoder log   *
 * if the verbosity level is 3 or higher.                               *
 *                                                                      *
 * bt_icpt ( rimnem, cimnem, *iret )                                    *
 *                                                                      *
 * Input parameter:                                                     *
 *      rimnem[]        char            Interface mnemonics for reals   *
 *      cimnem[]        char            Interface mnemonics for chars   *
 *                                                                      *
 * Output parameter:                                                    *
 *      *ret            int             Return code                     *
 *                                         0 = normal return            *
 *                                                                      *
 **                                                                     *
 *Log:                                                                  *
 * R. Hollern/NCEP       8/2000                                         *
 * C. Caruso Magee/NCEP 02/2002   Rename DOCW to DROC.                  *
 * C. Caruso Magee/NCEP 03/2002   Add code to separately print current  *
 *                                depth/direction/speed and counter.    *
/***********************************************************************/

void bt_icpt( char rimnem[][8], char cimnem[][8], int *iret )

{
    int ierwlg;

    unsigned int jj, ndts, nddc, ntrk;

    char logmsg[201];

/*
**  Print out all of the single-level character interface values
**  that are not "missing".
*/
    for ( jj = 0; jj < NCIMN; jj++ ) {
	if ( cintfv.civals[jj][0] != CHSPAC ) {
	    sprintf( logmsg, "%s = ", outstr(cimnem[jj]) );
	    sprintf( &(logmsg[strlen(logmsg)]), "%s\n" ,
		     outstr(cintfv.civals[jj]) );
	    dc_wclg( 3, "DC", 2, logmsg, &ierwlg );
	}
    }

/*
**  Print out all of the single-level real interface values
**  that are not "missing".
*/
    for ( jj = 0; jj < NRSLMN; jj++ ) {
	if ( ! ERMISS( rintfv.rivals[jj] ) ) {
	    sprintf( logmsg, "%s = %10.2f\n",
		     outstr(rimnem[jj]), rintfv.rivals[jj] );
	    dc_wclg( 3, "DC", 2, logmsg, &ierwlg );
	}
    }

/*
**  Print out all of the multi-level interface values.
*/

/*
**  Print the depth, temperature, and salinity data.
*/
       ndts = ( unsigned int ) rintfv.rivals[(rintfp.irndts)-1];

       if ( ndts > 0 ) {
         sprintf( logmsg, "%s = %u\n",
	     outstr(rimnem[(rintfp.irndts)-1]), ndts );
         dc_wclg( 3, "DC", 2, logmsg, &ierwlg );

         strcpy(   logmsg,      outstr(rimnem[(rintfp.irdbss[0])-1]) );
	 strcpy( &(logmsg[8]),  outstr(rimnem[(rintfp.irstmp[0])-1]) );
	 strcpy( &(logmsg[16]),  outstr(rimnem[(rintfp.irsaln[0])-1]) );
	 dc_wclg( 3, "DC", 2, logmsg, &ierwlg );

	 for ( jj = 0; jj < ndts; jj++ ) {
	    sprintf( logmsg,
		     "%8.2f %8.2f %8.2f\n",
		     rintfv.rivals[(rintfp.irdbss[jj])-1],
		     rintfv.rivals[(rintfp.irstmp[jj])-1],
		     rintfv.rivals[(rintfp.irsaln[jj])-1]);
	    dc_wclg( 3, "DC", 2, logmsg, &ierwlg );
         }
      }

/*
**  Print the depth, direction, and speed of current data.
*/
       nddc = ( unsigned int ) rintfv.rivals[(rintfp.irnddc)-1];

       if ( nddc > 0 ) {
         sprintf( logmsg, "%s = %u\n",
	     outstr(rimnem[(rintfp.irnddc)-1]), nddc );
         dc_wclg( 3, "DC", 2, logmsg, &ierwlg );

         strcpy(   logmsg,      outstr(rimnem[(rintfp.irdbsc[0])-1]) );
	 strcpy( &(logmsg[8]),  outstr(rimnem[(rintfp.irdroc[0])-1]) );
	 strcpy( &(logmsg[16]),  outstr(rimnem[(rintfp.irspoc[0])-1]) );
	 dc_wclg( 3, "DC", 2, logmsg, &ierwlg );

	 for ( jj = 0; jj < nddc; jj++ ) {
	    sprintf( logmsg,
		     "%8.2f %8.2f %8.2f\n",
		     rintfv.rivals[(rintfp.irdbsc[jj])-1],
		     rintfv.rivals[(rintfp.irdroc[jj])-1],
		     rintfv.rivals[(rintfp.irspoc[jj])-1]);
	    dc_wclg( 3, "DC", 2, logmsg, &ierwlg );
         }
      }

/*
**  Print the averaging periods of the TRACKOB parameters.
*/
       ntrk = ( unsigned int ) rintfv.rivals[(rintfp.irntrk)-1];

       if ( ntrk > 0 ) {
         sprintf( logmsg, "%s = %u\n",
	       outstr(rimnem[(rintfp.irntrk)-1]), ntrk );
         dc_wclg( 3, "DC", 2, logmsg, &ierwlg );

         strcpy(   logmsg,      outstr(rimnem[(rintfp.iravgp[0])-1]) );
	 dc_wclg( 3, "DC", 2, logmsg, &ierwlg );

	 for ( jj = 0; jj < ntrk; jj++ ) {
	    sprintf( logmsg,
		     "%8.2f\n",
		     rintfv.rivals[(rintfp.iravgp[jj])-1] );
	    dc_wclg( 3, "DC", 2, logmsg, &ierwlg );
         }
       }

/*
**  Set return code.
*/
    *iret = 0;

    return;
}

char *outstr( char string[] ) {

    unsigned short ii;

    static char tmpstr[9];

/*
**  Return a null-terminated copy of string.
*/
    for ( ii = 0; ii < 8; ii++ ) {
	tmpstr[ii] = string[ii];
    }
    tmpstr[8] = '\0';

    return tmpstr;
}
